ReflectionServiceBase class abstract

Constructors

ReflectionServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getAuthnDescriptor(ServiceCall call, GetAuthnDescriptorRequest request) → Future<GetAuthnDescriptorResponse>
getAuthnDescriptor_Pre(ServiceCall call, Future<GetAuthnDescriptorRequest> request) → Future<GetAuthnDescriptorResponse>
getChainDescriptor(ServiceCall call, GetChainDescriptorRequest request) → Future<GetChainDescriptorResponse>
getChainDescriptor_Pre(ServiceCall call, Future<GetChainDescriptorRequest> request) → Future<GetChainDescriptorResponse>
getCodecDescriptor(ServiceCall call, GetCodecDescriptorRequest request) → Future<GetCodecDescriptorResponse>
getCodecDescriptor_Pre(ServiceCall call, Future<GetCodecDescriptorRequest> request) → Future<GetCodecDescriptorResponse>
getConfigurationDescriptor(ServiceCall call, GetConfigurationDescriptorRequest request) → Future<GetConfigurationDescriptorResponse>
getConfigurationDescriptor_Pre(ServiceCall call, Future<GetConfigurationDescriptorRequest> request) → Future<GetConfigurationDescriptorResponse>
getQueryServicesDescriptor(ServiceCall call, GetQueryServicesDescriptorRequest request) → Future<GetQueryServicesDescriptorResponse>
getQueryServicesDescriptor_Pre(ServiceCall call, Future<GetQueryServicesDescriptorRequest> request) → Future<GetQueryServicesDescriptorResponse>
getTxDescriptor(ServiceCall call, GetTxDescriptorRequest request) → Future<GetTxDescriptorResponse>
getTxDescriptor_Pre(ServiceCall call, Future<GetTxDescriptorRequest> request) → Future<GetTxDescriptorResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited