QueryServiceBase class abstract

Constructors

QueryServiceBase()

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
params(ServiceCall call, QueryParamsRequest request) → Future<QueryParamsResponse>
params_Pre(ServiceCall call, Future<QueryParamsRequest> request) → Future<QueryParamsResponse>
signingInfo(ServiceCall call, QuerySigningInfoRequest request) → Future<QuerySigningInfoResponse>
signingInfo_Pre(ServiceCall call, Future<QuerySigningInfoRequest> request) → Future<QuerySigningInfoResponse>
signingInfos(ServiceCall call, QuerySigningInfosRequest request) → Future<QuerySigningInfosResponse>
signingInfos_Pre(ServiceCall call, Future<QuerySigningInfosRequest> request) → Future<QuerySigningInfosResponse>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited