ABCIApplicationServiceBase class abstract

Properties

$name → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
applySnapshotChunk(ServiceCall call, RequestApplySnapshotChunk request) → Future<ResponseApplySnapshotChunk>
applySnapshotChunk_Pre(ServiceCall call, Future<RequestApplySnapshotChunk> request) → Future<ResponseApplySnapshotChunk>
beginBlock(ServiceCall call, RequestBeginBlock request) → Future<ResponseBeginBlock>
beginBlock_Pre(ServiceCall call, Future<RequestBeginBlock> request) → Future<ResponseBeginBlock>
checkTx(ServiceCall call, RequestCheckTx request) → Future<ResponseCheckTx>
checkTx_Pre(ServiceCall call, Future<RequestCheckTx> request) → Future<ResponseCheckTx>
commit(ServiceCall call, RequestCommit request) → Future<ResponseCommit>
commit_Pre(ServiceCall call, Future<RequestCommit> request) → Future<ResponseCommit>
deliverTx(ServiceCall call, RequestDeliverTx request) → Future<ResponseDeliverTx>
deliverTx_Pre(ServiceCall call, Future<RequestDeliverTx> request) → Future<ResponseDeliverTx>
echo(ServiceCall call, RequestEcho request) → Future<ResponseEcho>
echo_Pre(ServiceCall call, Future<RequestEcho> request) → Future<ResponseEcho>
endBlock(ServiceCall call, RequestEndBlock request) → Future<ResponseEndBlock>
endBlock_Pre(ServiceCall call, Future<RequestEndBlock> request) → Future<ResponseEndBlock>
flush(ServiceCall call, RequestFlush request) → Future<ResponseFlush>
flush_Pre(ServiceCall call, Future<RequestFlush> request) → Future<ResponseFlush>
info(ServiceCall call, RequestInfo request) → Future<ResponseInfo>
info_Pre(ServiceCall call, Future<RequestInfo> request) → Future<ResponseInfo>
initChain(ServiceCall call, RequestInitChain request) → Future<ResponseInitChain>
initChain_Pre(ServiceCall call, Future<RequestInitChain> request) → Future<ResponseInitChain>
listSnapshots(ServiceCall call, RequestListSnapshots request) → Future<ResponseListSnapshots>
listSnapshots_Pre(ServiceCall call, Future<RequestListSnapshots> request) → Future<ResponseListSnapshots>
loadSnapshotChunk(ServiceCall call, RequestLoadSnapshotChunk request) → Future<ResponseLoadSnapshotChunk>
loadSnapshotChunk_Pre(ServiceCall call, Future<RequestLoadSnapshotChunk> request) → Future<ResponseLoadSnapshotChunk>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
offerSnapshot(ServiceCall call, RequestOfferSnapshot request) → Future<ResponseOfferSnapshot>
offerSnapshot_Pre(ServiceCall call, Future<RequestOfferSnapshot> request) → Future<ResponseOfferSnapshot>
query(ServiceCall call, RequestQuery request) → Future<ResponseQuery>
query_Pre(ServiceCall call, Future<RequestQuery> request) → Future<ResponseQuery>
setOption(ServiceCall call, RequestSetOption request) → Future<ResponseSetOption>
setOption_Pre(ServiceCall call, Future<RequestSetOption> request) → Future<ResponseSetOption>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited