SignatureData class abstract

SignatureData represents either a SingleSignatureData or MultiSignatureData. It is a convenience type that is easier to use in business logic than the encoded protobuf ModeInfo's and raw signatures.

Implementers

Constructors

SignatureData()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited