SignerData class

SignerData is the specific information needed to sign a transaction that generally isn't included in the transaction body itself

Constructors

SignerData({required String chainId, required Int64 accountNumber, required Int64 sequence})

Properties

accountNumber → Int64
accountNumber is the account number of the signer
final
chainId → String
chainId is the chain that this transaction is targeted
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → Int64
sequence is the account sequence number of the signer that is used for replay protection. This field is only useful for Legacy Amino signing, since in SIGN_MODE_DIRECT the account sequence is already in the signer info.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited