Bip32 class

Constructors

Bip32(Uint8List? privateKey, Uint8List? _publicKey, Uint8List chainCode, _NetworkType network, {int depth = 0, int index = 0, int parentFingerprint = 0x00000000})
Internal re-implementation of https://pub.dev/packages/bip32 waiting for null-safety update.
Bip32.fromPrivateKey({required Uint8List privateKey, required Uint8List chainCode, Bip32EccCurve? ecc})
factory
Bip32.fromPublicKey({required Uint8List publicKey, required Uint8List chainCode, Bip32EccCurve? ecc})
factory
Bip32.fromSeed(Uint8List seed)
factory

Properties

chainCode → Uint8List
final
depth ↔ int
getter/setter pair
fingerprint → Uint8List
no setter
hashCode → int
The hash code for this object.
no setterinherited
identifier → Uint8List
no setter
index ↔ int
getter/setter pair
network → _NetworkType
final
parentFingerprint ↔ int
getter/setter pair
privateKey → Uint8List?
final
publicKey ↔ Uint8List
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

derive(int index, {Bip32EccCurve? ecc}) → Bip32
deriveHardened(int index) → Bip32
derivePath(String path) → Bip32
isNeutered() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited