Bech32Encoder class

Allows to easily encode into Bech32 some data using a given human readable part.

Constructors

Bech32Encoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(String data) → Uint8List
encode(String humanReadablePart, Uint8List data) → String
Encodes the given data using the Bech32 encoding with the given human readable part