NetworkInfo class

Contains the information of a generic Cosmos-based network.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

NetworkInfo({required String bech32Hrp, required LCDInfo lcdInfo, required GRPCInfo grpcInfo})
NetworkInfo.fromJson(Map<String, dynamic> json)
factory
NetworkInfo.fromMultiHosts({required String bech32Hrp, required String grpc, required String lcd})
factory
NetworkInfo.fromSingleHost({required String bech32Hrp, required String host})
factory

Properties

bech32Hrp → String
Bech32 human readable part of the addresses related to this network
final
gRPCChannel → ClientChannel
Returns the ClientChannel that should be used to connect to the gRPC endpoint.
no setter
grpcInfo → GRPCInfo
Information about the gRPC endpoint to use
final
hashCode → int
The hash code for this object.
no setterinherited
lcdInfo → LCDInfo
Information about the LCD endpoint to use
final
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
restEndpoint → String
Returns the endpoint of the REST APIs that should be used to perform legacy queries.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.

Operators

operator ==(Object other) → bool
The equality operator.
inherited