BaseAccount class

Inheritance

Constructors

BaseAccount(BaseAccount account)

Properties

account → BaseAccount
final
accountNumber → Int64
no setteroverride
address → String
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
pubKey → Any
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence → Int64
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromAny(Any any) → BaseAccount